@@ -12,14 +12,12 @@ from ih import palette, helpers
 DEFAULT = {
     "palette": palette.PALETTE_DEFAULT,
     "scale": 1,
-    "colors": 256, 
+    "colors": 256,
     "render": False,
     "guidelines": False,
-    "print_ready": False,
-    "fileformat": "html", 
-    "save": True,
-    "output_format": "html"
-    }
+    "fileformat": "html",
+    "output_format": "html",
+}
 
 OUTPUT_FORMAT = ["html", "term"]
 
@@ -29,23 +27,38 @@ GUIDE = 10
 # Assuming no colour will be this in our palette.
 GUIDECOL = (0, 0, 0, 0)
 
-def debug_data(image_name, palette_name, chartimage, fileformat="html"):
+
+def debug_data(image_name, scale, colors, palette_name, chartimage, fileformat="html"):
     import pkg_resources
 
     ih_version = pkg_resources.require("ih")[0].version
-    data = (f'Image: {image_name}, {chartimage.height} x {chartimage.width}. ' +
-            f'Palette: {palette_name}. ih version {ih_version}.')
-    if fileformat=="html": 
-        return f'<div class="debug">{data}</div>'
+    data = [
+        f"Image: {image_name}",
+        f"Scale: {scale}x",
+        f"Image size: {chartimage.height} x {chartimage.width}",
+        f"Palette: {palette_name}",
+        f"Colors: {colors}",
+        f"ih version: {ih_version}",
+    ]
+    if fileformat == "html":
+        return f'<div class="debug">' + "<br>".join(data) + "</div>"
     else:
-        return f'\n{data}\n'
+        return "\n".join(data)
 
-def preprocess_image(im, pal=None, colors=DEFAULT["colors"], scale=DEFAULT["scale"], guidelines=DEFAULT["guidelines"]):
-    reduced_palette = palette.reduce_palette(pal, im)  # cap palette size at 256
+
+def preprocess_image(
+    im,
+    pal,
+    colors=DEFAULT["colors"],
+    scale=DEFAULT["scale"],
+    guidelines=DEFAULT["guidelines"],
+):
+    # Reduce palette to max 256 colors
+    reduced_palette = palette.reduce_palette(palette=pal, image=im)
     palette_image = palette.get_palette_image(reduced_palette)
     im = im.resize((int(im.width / scale), int(im.height / scale)))
 
-    # Remove black transparency issues with this one weird trick. 
+    # Remove black transparency issues with this one weird trick.
     alpha = im.convert("RGBA").split()[-1]
     bg = Image.new("RGBA", im.size, (255, 255, 255, 255))
     bg.paste(im, mask=alpha)
@@ -61,7 +74,8 @@ def preprocess_image(im, pal=None, colors=DEFAULT["colors"], scale=DEFAULT["scal
 
     return im._new(_im).convert("RGB")
 
-def get_legend(chartimage, print_ready=False): 
+
+def get_legend(chartimage):
     legend = {}
     styles = {}
     histogram = sorted(chartimage.getcolors())
@@ -78,22 +92,30 @@ def get_legend(chartimage, print_ready=False):
         else:
             color = "lightgray"
 
-        # force black/white if print_ready
-        if print_ready:
-            color = "black"
-            h = "white"
-
         styles[sclass] = {"bg": h, "rgb": rgb, "c": color, "star": star}
 
         legend[helpers.rgb2hex(x[1])] = STARS[idx % len(STARS)]
     return legend, styles, histogram
 
-def generate_html_chart(chartimage, palette_name, pal, render=False, guidelines=False, print_ready=False,  data=""):
+
+def generate_html_chart(
+    chartimage,
+    palette_name,
+    pal,
+    render=False,
+    guidelines=False,
+    data="",
+):
 
     html = ['<html><meta charset="UTF-8">']
 
     with open(helpers.base_path("styling").joinpath("styling.css")) as s:
-        html.append("<style>" + "".join(s.readlines()) + "</style>")
+        html.append("<style>")
+        if guidelines:
+            html.append(":root { --border: lightgrey; }")
+        else:
+            html.append(":root { --border: black; }")
+        html.append("".join(s.readlines()) + "</style>")
 
     if render:
         html.append(
@@ -113,7 +135,7 @@ def generate_html_chart(chartimage, palette_name, pal, render=False, guidelines=
             )
         )
 
-    legend, styles, histogram = get_legend(chartimage, print_ready)
+    legend, styles, histogram = get_legend(chartimage)
     after = {}
 
     html.append("<style>")
@@ -125,7 +147,10 @@ def generate_html_chart(chartimage, palette_name, pal, render=False, guidelines=
             html.append('.%s::after { content: "%s" }' % (x, y["star"]))
 
     if not render:
-        html.append('.%s::after { content: "%s" }' % (helpers.star_class(helpers.WHITESTAR), helpers.WHITESTAR))
+        html.append(
+            '.%s::after { content: "%s" }'
+            % (helpers.star_class(helpers.WHITESTAR), helpers.WHITESTAR)
+        )
 
     html.append("</style>")
 
@@ -148,7 +173,9 @@ def generate_html_chart(chartimage, palette_name, pal, render=False, guidelines=
 
         html.append(
             "<tr>"
-            + helpers.color_cell(color=color, star=legend[color], thread=False, legend=True)
+            + helpers.color_cell(
+                color=color, star=legend[color], thread=False, legend=True
+            )
             + "<td>{}</td><td>{}</td></tr>".format(count, code)
         )
 
@@ -156,10 +183,17 @@ def generate_html_chart(chartimage, palette_name, pal, render=False, guidelines=
 
     html.append(f'<div class="debug">{data}</div>')
 
+    # If using guidelines, enable printhacks
+    if guidelines:
+        with open(helpers.base_path("styling").joinpath("styling.html")) as s:
+            html.append("".join(s.readlines()))
+
     html.append("</div>")  # end left-content
+    html.append("<div class='page-break'></div>")  # force page break
 
     html.append('<div class="right-content"><div class="chart">')
 
+    # If using guidelines, expand the image to a whole number of guidelines first.
     if guidelines:
         chartimage = chartimage.convert("RGBA")
         xpad = GUIDE - (chartimage.width % GUIDE)
@@ -169,6 +203,7 @@ def generate_html_chart(chartimage, palette_name, pal, render=False, guidelines=
 
         chartimage = ImageOps.expand(chartimage, padding, fill=GUIDECOL)
 
+    # Generate Chart (TODO(glasnt): make this less terrible)
     CENTER = True
     for y in range(0, chartimage.height):
 
@@ -197,7 +232,12 @@ def generate_html_chart(chartimage, palette_name, pal, render=False, guidelines=
                         CENTER = False
 
             row.append(
-                helpers.color_cell(color=p, star=legend[p], center=center_flag, guide=[guide_x, guide_y])
+                helpers.color_cell(
+                    color=p,
+                    star=legend[p],
+                    center=center_flag,
+                    guide=[guide_x, guide_y],
+                )
             )
 
         html.append("<div class='r'>" + "".join(row) + "</div>")
@@ -214,8 +254,8 @@ def save_chart(html, image, fileformat):
 
     return outfile
 
-def generate_term_chart(chartimage, pal, render, palette_name, data):
 
+def generate_term_chart(chartimage, pal, render, palette_name, data):
     def c(text, bg=None, fg=None):
         def color(rgb, code):
             if not rgb:
@@ -235,15 +275,14 @@ def generate_term_chart(chartimage, pal, render, palette_name, data):
         result = foreground(fg) + background(bg) + text + reset()
         return result
 
-
     def star(rgb, render=False):
         p = helpers.rgb2hex(rgb)
         if render:
             return c("  ", bg=rgb)
         else:
-            return c(legend[p], fg=rgb) + " "   
+            return c(legend[p], fg=rgb) + " "
 
-    legend, styles, histogram = get_legend(chartimage, print_ready=False)
+    legend, styles, histogram = get_legend(chartimage)
 
     headers = ["*", palette.get_identity_name(palette_name), f"{palette_name} code"]
     table = []
@@ -255,7 +294,7 @@ def generate_term_chart(chartimage, pal, render, palette_name, data):
         thread = palette.thread_name(rgb, pal)
         code = thread["code"]
         symbol = star(rgb, render=render)
-        
+
         table.append([symbol, str(count), code])
 
     result += tabulate(table, headers=headers)
@@ -266,24 +305,21 @@ def generate_term_chart(chartimage, pal, render, palette_name, data):
         for x in range(0, chartimage.width):
             rgb = chartimage.getpixel((x, y))
             row.append(star(rgb, render=render))
-    
+
         result += "".join(row) + "\n"
-    result += data
+    result += "\n" + data
     return result
-        
-    
+
 
 def chart(
     image_name=None,
     image_obj=None,
-    palette_name=DEFAULT["palette"], #PALETTE_DEFAULT,
-    scale=DEFAULT['scale'],
-    colors=DEFAULT['colors'],
-    render=DEFAULT['render'],
-    guidelines=DEFAULT['guidelines'],
-    fileformat=DEFAULT['fileformat'],
-    save=DEFAULT['save'],
-    print_ready=DEFAULT['print_ready'],
+    palette_name=DEFAULT["palette"],  # PALETTE_DEFAULT,
+    scale=DEFAULT["scale"],
+    colors=DEFAULT["colors"],
+    render=DEFAULT["render"],
+    guidelines=DEFAULT["guidelines"],
+    fileformat=DEFAULT["fileformat"],
 ):
     # can't have both guidelines and rendering
     if render:
@@ -301,15 +337,28 @@ def chart(
         im, pal=pal, colors=colors, scale=scale, guidelines=guidelines
     )
 
-    data = debug_data(image_name, palette_name, chartimage, fileformat)
+    data = debug_data(
+        image_name=image_name,
+        scale=scale,
+        colors=colors,
+        palette_name=palette_name,
+        chartimage=chartimage,
+        fileformat=fileformat,
+    )
 
     if fileformat == "html":
-        chart = generate_html_chart(chartimage, palette_name=palette_name, pal=pal, render=render, guidelines=guidelines, print_ready=print_ready, data=data)
-    if fileformat == "term":
-        chart = generate_term_chart(chartimage, pal=pal, render=render, palette_name=palette_name, data=data)
-
-    if save:
+        chart = generate_html_chart(
+            chartimage,
+            palette_name=palette_name,
+            pal=pal,
+            render=render,
+            guidelines=guidelines,
+            data=data,
+        )
         saved = save_chart(chart, image_name, fileformat)
         return saved
-    else:
+    elif fileformat == "term":
+        chart = generate_term_chart(
+            chartimage, pal=pal, render=render, palette_name=palette_name, data=data
+        )
         return chart
